@@ -41,26 +41,24 @@ class BitmexClient:
         for symbol in symbols:
             i = 0
             while True:
-                for symbol in symbols:
-                    try:
-                        histories[symbol] = self.client.Trade.Trade_getBucketed(symbol=symbol,
-                                                                                binSize=binSize,
-                                                                                count=count,
-                                                                                reverse=True,
-                                                                                ).result()
-                    except HTTPBadRequest as e:
-                        if 'expired' in str(e):
-                            print('Getting {} history failed. Expired error.'.format(
-                                symbol), flush=True)
-                        else:
-                            time.sleep(2)  # try again after 2 seconds
-                            print("Can't get history. Trying again...", e)
-                            i += 1
-                            if i > 1:
-                                print("Can't get history for 2nd time.")
-                                return False
-                            else:
-                                continue
+                try:
+                    histories[symbol] = self.client.Trade.Trade_getBucketed(symbol=symbol,
+                                                                            binSize=binSize,
+                                                                            count=count,
+                                                                            reverse=True,
+                                                                            ).result()
+                    break
+                except HTTPBadRequest as e:
+                    if 'expired' in str(e):
+                        print('Getting {} history failed. Expired error.'.format(
+                            symbol), flush=True)
+                    else:
+                        time.sleep(2)  # try again after 2 seconds
+                        print("Can't get history. Trying again...", e)
+                        i += 1
+                        if i > 1:
+                            print("Can't get history for 2nd time.")
+                            break
         return histories
 
     def get_current_price(self, symbol):
@@ -81,9 +79,9 @@ class BitmexClient:
                     current_price = self.get_current_price(symbol)
                     if current_price:
                         break
-            else:
-                print('API error getting current price', e, flush=True)
-                pass
+            # else:
+            #     # print('API error getting current price', e, flush=True)
+            #     pass
             return self.last_current_price(symbol)
 
     def last_current_price(self, symbol):
@@ -273,6 +271,11 @@ class BitmexOrder:
 
     def bracket_stop_order(self, symbol, orderQty, entry, sl, tp=0):
         try:
+            if self.props[symbol]['qty'] != 0:
+                # order is open (shouldn't be)
+                # then close old order first
+                self.close(symbol)
+                time.sleep(1)
             self.props[symbol]['stop_id'] = self.generate_id(symbol)
             order_res = self.client.client.Order.Order_new(
                 symbol=symbol, ordType='Stop', clOrdID=self.props[symbol]['stop_id'], orderQty=orderQty,
@@ -341,7 +344,18 @@ class BitmexOrder:
                 close = self.client.client.Order.Order_new(
                     symbol=symbol, ordType='Market', execInst='Close', orderQty=qty
                 ).result()
+                time.sleep(2)  # wait before making new API call
                 self.stoploss_cancel(symbol)
+                if self.props[symbol]['qty'] > 0:
+                    self.props[symbol]['open'] = False
+                    print("Long Position {} closed. {} Contracts from {} to {}. PnL in Points: {}".format(symbol,
+                                                                                                          self.props[symbol]['qty'], self.props[symbol]['entry'], self.props[symbol]['SL'], self.price_decimals(symbol, self.props[symbol]['SL']-self.props[symbol]['entry'])), flush=True)
+                    self.props[symbol]['qty'] = 0
+                elif self.props[symbol]['qty'] < 0:
+                    self.props[symbol]['open'] = False
+                    print("Short Position {} closed. {} Contracts from {} to {}. PnL in Points: {}".format(symbol,
+                                                                                                           -self.props[symbol]['qty'], self.props[symbol]['entry'], self.props[symbol]['SL'], self.price_decimals(symbol, self.props[symbol]['entry']-self.props[symbol]['SL'])), flush=True)
+                    self.props[symbol]['qty'] = 0
                 return close
             except HTTPBadRequest as e:
                 print("Error closing order in {}.".format(symbol), e, flush=True)
