@@ -9,6 +9,7 @@ import os
 import signal
 import sys
 
+from socket import gaierror
 
 class Lotus:
     def __init__(self, client, symbols, settings, setting_file_name):
@@ -71,10 +72,21 @@ class Lotus:
                   "It could be that you are timed out because you try to access with multiple IP's.\nIn this case wait 40 minutes to be able to access again.\(Don't need to restart)".format(
                       self._api_endpoint, self.settings.token))
             return False
+        except (requests.exceptions.Timeout, requests.exceptions.ConnectionError, gaierror):
+            time.sleep(30)
+            print('Retrying connection to endpoint')
+            return self.get_api_signal()
+        except requests.exceptions.TooManyRedirects:
+            print('Bad URL. Try to setup the correct endpoint. Current endpoint: {}'.format(self._api_endpoint))
+            return False
+        except requests.exceptions.RequestException as e:
+            print('Another exception occured {}'.format(e))
+            return False
 
     def is_new_signal(self, signal):
         # tests if signal has new timestamp
         if signal['timestamp'] != self._last_signal_timestamp:
+            self._last_signal_timestamp = signal['timestamp']
             return True
         else:
             return False
@@ -98,7 +110,6 @@ class Lotus:
             self.order.stoporder_cancel(symbol)
             time.sleep(3)
         elif self.order.props[symbol]['open']:
-            print("Close old order {} first, because of new signal".format(symbol))
             self.order.close(symbol, -self.client.open_contracts(symbol))
             time.sleep(3)
 
